import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Scanner;

class Record {
private int id;
private String name;
private String value;

public Record(int id, String name, String value) {
this.id = id;
this.name = name;
this.value = value;
}

public int getId() {
return id;
}

public String getName() {
return name;
}

public String getValue() {
return value;
}

public void setValue(String value) {
this.value = value;
}

@Override
public String toString() {
return String.format("%d,%s,%s%n", id, name, value);
}
}

public class SimpleDatabase {
private static final String DB_FILE = "database.txt";
private List<Record> records;

public SimpleDatabase() {
records = new ArrayList<>();
loadFromFile();
}

public void addRecord(Record record) {
records.add(record);
saveToFile();
}

public void updateRecord(Record record) {
for (int i = 0; i < records.size(); i++) {
if (records.get(i).getId() == record.getId()) {
records.set(i, record);
saveToFile();
break;
}
}
}

public void deleteRecord(int id) {
for (int i = 0; i < records.size(); i++) {
if (records.get(i).getId() == id) {
records.remove(i);
saveToFile();
break;
}
}
}

public Record findRecord(int id) {
for (Record record : records) {
if (record.getId() == id) {
return record;
}
}
return null;
}

public void viewRecords() {
System.out.println("ID\tName\tValue");
for (Record record : records) {
System.out.println(record);
}
}

private void loadFromFile() {
try (BufferedReader reader = new BufferedReader(new FileReader(DB_FILE))) {
String line;
while ((line = reader.readLine()) != null) {
String[] parts = line.split(",");
int id = Integer.parseInt(parts[0]);
String name = parts[1];
String value = parts[2];
records.add(new Record(id, name, value));
}
} catch (IOException e) {
System.out.println("Error loading database: " + e.getMessage());
}
}

private void saveToFile() {
try (BufferedWriter writer = new BufferedWriter(new FileWriter(DB_FILE))) {
for (Record record : records) {
writer.write(record.toString());
}
} catch (IOException e) {
System.out.println("Error saving database: " + e.getMessage());
}
}

public static void main(String[] args) {
SimpleDatabase db = new SimpleDatabase();
Scanner scanner = new Scanner(System.in);

while (true) {
System.out.println("Simple Database:");
System.out.println("1. Add record");
System.out.println("2. Update record");
System.out.println("3. Delete record");
}